All files / src type.ts

100% Statements 1/1
100% Branches 0/0
100% Functions 0/0
100% Lines 1/1

Press n or j to go to the next uncovered block, b, p or k for the previous block.

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45                                                                          6x              
import { NAVIGATION_STATE } from "./const";
 
export type NavigationState =
  (typeof NAVIGATION_STATE)[keyof typeof NAVIGATION_STATE];
export type TransportMode = "WALK" | "BIKE" | "BUS" | "SHUTTLE" | "CAR";
export type Coordinate = { latitude: number; longitude: number };
export type NamedCoordinate = Coordinate & { name?: string }; // includes name for destination marker
 
export type TransportModeApi =
  | "walking"
  | "driving"
  | "bicycling"
  | "transit"
  | "shuttle";
 
export type ManeuverTypeApi =
  | "TURN_SLIGHT_LEFT"
  | "TURN_SHARP_LEFT"
  | "TURN_LEFT"
  | "TURN_SLIGHT_RIGHT"
  | "TURN_SHARP_RIGHT"
  | "TURN_RIGHT"
  | "KEEP_RIGHT"
  | "KEEP_LEFT"
  | "UTURN_LEFT"
  | "UTURN_RIGHT"
  | "STRAIGHT"
  | "RAMP_LEFT"
  | "RAMP_RIGHT"
  | "MERGE"
  | "FORK_LEFT"
  | "FORK_RIGHT"
  | "FERRY"
  | "FERRY_TRAIN"
  | "ROUNDABOUT_LEFT"
  | "ROUNDABOUT_RIGHT";
 
export const TRANSPORT_MODE_API_MAP: Record<TransportMode, TransportModeApi> = {
  WALK: "walking",
  BIKE: "bicycling",
  BUS: "transit",
  SHUTTLE: "shuttle",
  CAR: "driving",
};